autowisp.database.data_model.image module — AutoWISP documentation

# autowisp.database.data_model.image module

## Class Inheritance Diagram

Define the image table for the pipeline

class autowisp.database.data_model.image.Image(**kwargs)

  Bases: `DataModelBase`

  The table describing the image specified

  id

    A unique identifier for each row.

  image_type
  image_type_id

    The id of the image type

  notes

    The notes provided for the image

  observing_session
  observing_session_id

    The id of the observing session

  processing: Mapped[List[ProcessedImages]]
  raw_fname

    The full path of the raw image

  timestamp

    When record was last changed

class autowisp.database.data_model.image.ImageProcessingProgress(**kwargs)

  Bases: `DataModelBase`

  The table describing the Image Processing Progress

  applied_to: Mapped[List[ProcessedImages]]
  configuration_version

    config version of image

  finished

    The time processing is known to have ended (NULL if possibly still on-going)

  host

    Hostname or other identifier of the computer where processing is/was done

  id

    A unique identifier for each row.

  image_type
  image_type_id

    The id of the image type being processed

  notes

    Any user supplied notes about the processing.

  process_id

    Identifier of the process performing this calibration step

  started

    The time processing started

  step
  step_id

    Id of the step that was applied

  timestamp

    When record was last changed

class autowisp.database.data_model.image.ProcessedImages(**kwargs)

  Bases: `DataModelBase`

  The table describing the processed images/channels by each step.

  channel

    The channel of the image that was processed.

  final

    Is this the final processing status? The only case where `status=1` is not final is for magnitude fitting, where there may be additional iterations needed.

  id

    A unique identifier for each row.

  image
  image_id

    The image that was processed.

  processing
  progress_id

    The id of the processing progress

  status

    The status of the processing (0 = started, >0 = successfully saved progress, negative values indicate various reasons for failure). The meaning of negative values is step dependent. For most steps 1 is the final status, but for magnitude fitting the value indicates the iteration.

  timestamp

    When record was last changed